==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/start/dialogs_nl.lua <==

dialogId("1st-m-cotobylo", "font_small", "What was that?")
dialogStr("Wat was dat?")


dialogId("1st-v-netusim", "font_big", "I have no idea.")
dialogStr("Ik heb geen idee.")


dialogId("1st-v-ven", "font_big", "We should go and have a look outside.")
dialogStr("We kunnen beter even buiten gaan kijken.")


dialogId("1st-m-pockej", "font_small", "Wait! I`m going with you.")
dialogStr("Wacht even! Ik ga met je mee.")


dialogId("1st-m-proc", "font_small", "Why isn`t anything happening?")
dialogStr("Waarom gebeurt er niks?")


dialogId("1st-m-hej", "font_small", "Hey, player!")
dialogStr("Hee, speler!")


dialogId("1st-v-navod1", "font_big", "You can control us with arrow keys and use the space bar to switch fish.")
dialogStr("Je kunt ons besturen met de pijltjestoetsen en met de spatiebalk wissel je van vis.")


dialogId("1st-m-navod4", "font_small", "Or you can control us with the mouse -- left-click somewhere and...")
dialogStr("Of je kunt ons met de muis besturen -- klik met de linker knop ergens en...")


dialogId("1st-v-navod5", "font_big", "...if we can get there without moving anything...")
dialogStr("...als we daarheen kunnen gaan zonder iets te verplaatsen...")


dialogId("1st-m-navod6", "font_small", "...we`ll follow your clicks.")
dialogStr("...volgen we je geklik.")


dialogId("1st-v-navod7", "font_big", "And when you right-click somewhere, we`ll try to get there, pushing aside all obstacles in our way.")
dialogStr("En als je ergens met de rechter knop klikt, dan proberen we daar heen te gaan en alle obstakels die we onderweg tegen komen opzij te duwen.")


dialogId("1st-m-navod8", "font_small", "Your goal should be to get both of us outside.")
dialogStr("De bedoeling is dat je ons allebei naar buiten leidt.")


dialogId("1st-v-davej", "font_big", "And be careful not to hurt us. If you drop something on us or...")
dialogStr("En wees wel voorzichtig met ons. Als je iets op ons laat vallen...")


dialogId("1st-m-nechtoho", "font_small", "Oh, stop it. We`ll tell him in the next level.")
dialogStr("Oh, hou op. Dat vertellen we hem in het volgende veld wel.")


dialogId("1st-v-takdobre", "font_big", "Okay.")
dialogStr("Goed.")


dialogId("1st-m-neprojedu", "font_small", "I can`t get through here. That steel cylinder is in the way.")
dialogStr("Ik kom hier niet doorheen. Deze stalen cylinder zit in de weg.")


dialogId("1st-m-nepohnu", "font_small", "I can`t move that cylinder. Can you help me?")
dialogStr("Ik kan die cylinder niet verplaatsen. Kun je me helpen?")


dialogId("1st-v-takukaz", "font_big", "No problem...")
dialogStr("Geen probleem...")


dialogId("1st-m-hmmm", "font_small", "Wow, you moved it! I could never do that!")
dialogStr("Gaaf, je hebt hem verplaatst. Dat zou ik nooit kunnen!")


dialogId("1st-m-diky", "font_small", "Thanks, now I can go with you.")
dialogStr("Bedankt, nu kan ik met je mee gaan.")


dialogId("1st-v-nemuzu", "font_big", "Darn it, I can`t get through.")
dialogStr("Verdikkeme, ik kan er niet door.")


dialogId("1st-v-pribral", "font_big", "I must have gained some weight.")
dialogStr("Misschien ben ik wat aangekomen.")


dialogId("1st-v-posunout", "font_big", "Could you push the chair a little bit to the left?")
dialogStr("Kun je die stoel een beetje naar links schuiven?")


dialogId("1st-v-chyba", "font_big", "Ooops! That was a mistake. Both of us have to be able to leave in order to continue.")
dialogStr("Oeps! Dat was niet goed. We moeten allebei ontsnappen om verder te kunnen.")


dialogId("1st-v-nedostanu", "font_big", "There`s no way I can get out now. You`ll have to restart the level.")
dialogStr("Hier kom ik nooit meer uit. Je zult het veld van voren af aan moeten beginnen.")


dialogId("1st-v-stiskni", "font_big", "You have to press the long arrow on your keyboard.")
dialogStr("Je moet op die lange pijl op je toetsenbord drukken.")


dialogId("1st-m-backspace", "font_small", "Humans call it a backspace key.")
dialogStr("Mensen noemen dat de backspace toets.")


dialogId("1st-v-jedno", "font_big", "Whatever. It was funnier in Czech.")
dialogStr("Laat maar. In het tjechisch was het grappiger.")


dialogId("1st-v-najit", "font_big", "The restart option is also located on the control panel.")
dialogStr("De optie om te herstarten zit ook op het controle paneel.")


dialogId("1st-m-pokud", "font_small", "If you think you would rather restart the level, no problem.")
dialogStr("Als je denkt dat je liever opnieuw begint met een veld, dan is dat geen probleem.")


dialogId("1st-v-znovu", "font_big", "You just have to press the long arrow on your keyboard.")
dialogStr("Druk op de knop met de lange pijl.")


dialogId("1st-x-ocel", "font_darkgrey", "I`m a heavy steel cylinder. It`s not easy to move me around. Such a tiny fish, like the orange one over there, simply has no chance. I could smash her without any problem.")
dialogStr("Ik ben een zware stalen cylinder. Het is niet makkelijk om mij te verplaatsen. Een klein visje als dat oranje visje daar heeft gewoon geen kans. Ik zou haar zonder problemen verpletten.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/start/dialogs_nl.lua <==

dialogId("1st-m-cotobylo", "font_small", "What was that?")
dialogStr("Wat was dat?")


dialogId("1st-v-netusim", "font_big", "I have no idea.")
dialogStr("Ik heb geen idee.")


dialogId("1st-v-ven", "font_big", "We should go and have a look outside.")
dialogStr("We kunnen beter even buiten gaan kijken.")


dialogId("1st-m-pockej", "font_small", "Wait! I’m going with you.")
dialogStr("Wacht even! Ik ga met je mee.")


dialogId("1st-m-proc", "font_small", "Why isn’t anything happening?")
dialogStr("Waarom gebeurt er niks?")


dialogId("1st-m-hej", "font_small", "Hey, player!")
dialogStr("Hee, speler!")


dialogId("1st-v-navod1", "font_big", "You can control us with arrow keys and use the space bar to switch fish.")
dialogStr("Je kunt ons besturen met de pijltjestoetsen en met de spatiebalk wissel je van vis.")


dialogId("1st-m-navod4", "font_small", "Or you can control us with the mouse -- left-click somewhere and...")
dialogStr("Je kunt ons ook met de muis besturen -- klik met de linker knop ergens en...")


dialogId("1st-v-navod5", "font_big", "...if we can get there without moving anything...")
dialogStr("...als we daarheen kunnen gaan zonder iets te verplaatsen...")


dialogId("1st-m-navod6", "font_small", "...we’ll follow your clicks.")
dialogStr("...volgen we je geklik.")


dialogId("1st-v-navod7", "font_big", "And when you right-click somewhere, we’ll try to get there, pushing aside all obstacles in our way.")
dialogStr("En als je ergens met de rechter knop klikt, dan proberen we daar heen te gaan en alle obstakels die we onderweg tegen komen opzij te duwen.")


dialogId("1st-m-navod8", "font_small", "Your goal should be to get both of us outside.")
dialogStr("De bedoeling is dat je ons allebei naar buiten leidt.")


dialogId("1st-v-davej", "font_big", "And be careful not to hurt us. If you drop something on us or...")
dialogStr("En wees wel voorzichtig met ons. Als je iets op ons laat vallen...")


dialogId("1st-m-nechtoho", "font_small", "Oh, stop it. We’ll tell him in the next level.")
dialogStr("Oh, hou op. Dat vertellen we in het volgende veld wel.")


dialogId("1st-v-takdobre", "font_big", "Okay.")
dialogStr("Goed.")


dialogId("1st-m-neprojedu", "font_small", "I can’t get through here. That steel cylinder is in the way.")
dialogStr("Ik kom hier niet doorheen. Deze stalen cylinder zit in de weg.")


dialogId("1st-m-nepohnu", "font_small", "I can’t move that cylinder. Can you help me?")
dialogStr("Ik kan die cylinder niet verplaatsen. Kun je me helpen?")


dialogId("1st-v-takukaz", "font_big", "No problem...")
dialogStr("Geen probleem...")


dialogId("1st-m-hmmm", "font_small", "Wow, you moved it! I could never do that!")
dialogStr("Wow, je hebt hem verplaatst. Dat zou ik nooit kunnen!")


dialogId("1st-m-diky", "font_small", "Thanks, now I can go with you.")
dialogStr("Bedankt, nu kan ik mee naar buiten.")


dialogId("1st-v-nemuzu", "font_big", "Darn it, I can’t get through.")
dialogStr("Verdomme, ik kan er niet door.")


dialogId("1st-v-pribral", "font_big", "I must have gained some weight.")
dialogStr("Misschien ben ik wat aangekomen.")


dialogId("1st-v-posunout", "font_big", "Could you push the chair a little bit to the left?")
dialogStr("Kun je die stoel een beetje naar links schuiven?")


dialogId("1st-v-chyba", "font_big", "Ooops! That was a mistake. Both of us have to be able to leave in order to continue.")
dialogStr("Oeps! Dat was niet goed. We moeten allebei ontsnappen om verder te kunnen.")


dialogId("1st-v-nedostanu", "font_big", "There’s no way I can get out now. You’ll have to restart the level.")
dialogStr("Hier kom ik nooit meer uit. Je zult het veld opnieuw moeten spelen.")


dialogId("1st-v-stiskni", "font_big", "You have to press the long arrow on your keyboard.")
dialogStr("Je moet op die lange pijl op je toetsenbord drukken.")


dialogId("1st-m-backspace", "font_small", "Humans call it a backspace key.")
dialogStr("Mensen noemen dat de backspace toets.")


dialogId("1st-v-jedno", "font_big", "Whatever. It was funnier in Czech.")
dialogStr("Laat maar. In het tjechisch was het grappiger.")


dialogId("1st-v-najit", "font_big", "The restart option is also located on the control panel.")
dialogStr("De optie om te herstarten zit ook op het controle paneel.")


dialogId("1st-m-pokud", "font_small", "If you think you would rather restart the level, no problem.")
dialogStr("Als je denkt dat je liever opnieuw begint met een veld, dan is dat geen probleem.")


dialogId("1st-v-znovu", "font_big", "You just have to press the long arrow on your keyboard.")
dialogStr("Druk op de knop met de lange pijl.")


dialogId("1st-x-ocel", "font_darkgrey", "I’m a heavy steel cylinder. It’s not easy to move me around. Such a tiny fish, like the orange one over there, simply has no chance. I could smash her without any problem.")
dialogStr("Ik ben een zware stalen cylinder. Het is niet makkelijk om mij te verplaatsen. Een klein visje als dat oranje visje daar heeft gewoon geen kans. Ik zou haar gewoon verpletten.")
